@@ -40,10 +40,6 @@ main(int argc, char **argv)
     XfdesktopApplication *app;
     int ret = 0;
 
-#if !GLIB_CHECK_VERSION (2, 36, 0)
-    g_type_init();
-#endif
-
 #ifdef G_ENABLE_DEBUG
     /* do NOT remove this line. If something doesn't work,
      * fix your code instead! */
