@@ -61,7 +61,7 @@ struct _XfdesktopIconViewClass
     void (*select_cursor_item)(XfdesktopIconView *icon_view);
     void (*toggle_cursor_item)(XfdesktopIconView *icon_view);
 
-    gboolean (*activate_cursor_item)(XfdesktopIconView *icon_view);
+    gboolean (*activate_selected_items)(XfdesktopIconView *icon_view);
 
     gboolean (*move_cursor)(XfdesktopIconView *icon_view,
                             GtkMovementStep step,
@@ -125,6 +125,14 @@ void xfdesktop_icon_view_set_center_text (XfdesktopIconView *icon_view,
 
 GtkWidget *xfdesktop_icon_view_get_window_widget(XfdesktopIconView *icon_view);
 
+gboolean
+xfdesktop_get_workarea_single(XfdesktopIconView *icon_view,
+                              guint ws_num,
+                              gint *xorigin,
+                              gint *yorigin,
+                              gint *width,
+                              gint *height);
+
 void xfdesktop_icon_view_sort_icons(XfdesktopIconView *icon_view);
 
 #if defined(DEBUG) && DEBUG > 0
